require "test_helper"
require "sekoia/formatter"

class SEKOIA::FormatterTest < Test::Unit::TestCase
  def test_only_log
    log = SEKOIA::Formatter.format(log: "test-log")
    assert_equal log, "<14>1 - - - - - [SEKOIA@53288 intake_key=\"\"] test-log"
  end

  # RFC 3339
  # Adding fractional seconds: https://github.com/fluent/fluentd/issues/1862
  def test_with_timestamp
    log = SEKOIA::Formatter.format(timestamp: 0, log: "test-log")
    assert_equal log, "<14>1 1970-01-01T00:00:00.000000+00:00 - - - - [SEKOIA@53288 intake_key=\"\"] test-log"
  end

  def test_with_timestamp_nano
    log = SEKOIA::Formatter.format(timestamp: Fluent::EventTime.new(0, 123456000), log: "test-log")

    assert_equal log, "<14>1 1970-01-01T00:00:00.123456+00:00 - - - - [SEKOIA@53288 intake_key=\"\"] test-log"
  end

  def test_with_priority
    log = SEKOIA::Formatter.format( priority: 1, log: "test-log")
    assert_equal log, "<1>1 - - - - - [SEKOIA@53288 intake_key=\"\"] test-log"
  end

  def test_with_hostname
    log = SEKOIA::Formatter.format( hostname: "host", log: "test-log")
    assert_equal log, "<14>1 - host - - - [SEKOIA@53288 intake_key=\"\"] test-log"
  end

  def test_with_overly_long_hostname
    log = SEKOIA::Formatter.format( hostname: "a"*300, log: "test-log")
    assert_equal log, "<14>1 - #{"a"*255} - - - [SEKOIA@53288 intake_key=\"\"] test-log"
  end

  def test_with_app_name
    log = SEKOIA::Formatter.format( app_name: "app-name", log: "test-log")
    assert_equal log, "<14>1 - - app-name - - [SEKOIA@53288 intake_key=\"\"] test-log"
  end

  def test_with_overly_long_app_name
    log = SEKOIA::Formatter.format( app_name: "a"*300, log: "test-log")
    assert_equal log, "<14>1 - - #{"a"*48} - - [SEKOIA@53288 intake_key=\"\"] test-log"
  end

  def test_with_proc_id
    log = SEKOIA::Formatter.format( proc_id: "proc-id", log: "test-log")
    assert_equal log, "<14>1 - - - proc-id - [SEKOIA@53288 intake_key=\"\"] test-log"
  end

  def test_with_overly_long_proc_id
    log = SEKOIA::Formatter.format( proc_id: "a"*300, log: "test-log")
    assert_equal log, "<14>1 - - - #{"a"*128} - [SEKOIA@53288 intake_key=\"\"] test-log"
  end

  def test_with_msg_id
    log = SEKOIA::Formatter.format( msg_id: "msg-id", log: "test-log")
    assert_equal log, "<14>1 - - - - msg-id [SEKOIA@53288 intake_key=\"\"] test-log"
  end

  def test_with_overly_long_msg_id
    log = SEKOIA::Formatter.format( msg_id: "a"*300, log: "test-log")
    assert_equal log, "<14>1 - - - - #{"a"*32} [SEKOIA@53288 intake_key=\"\"] test-log"
  end

  def test_with_intake_key
    log = SEKOIA::Formatter.format( msg_id: "a"*300, log: "test-log", intake_key: "testIntakeKey")
    assert_equal log, "<14>1 - - - - #{"a"*32} [SEKOIA@53288 intake_key=\"testIntakeKey\"] test-log"
  end
end
